@@ -197,13 +197,13 @@ class Transaction(object):
             "TRACE_SOURCE": "PYTHON",
             "TRACE_TARGET": "RETRACE",
             "TRACE_VERSION": "{}".format(TRACE_CONTEXT_VERSION or "unknown"),
-            "HOST_NAME": system_info["hostname"],
-            "OS_TYPE": system_info["platform"].upper(),
+            "HOST_NAME": str(system_info["hostname"]),
+            "OS_TYPE": str(system_info["platform"].upper()),
             "PROCESS_ID": str(process_info["pid"]),
             "APPLICATION_PATH": "/",
-            "APPLICATION_FILESYSTEM_PATH": application_info["base_dir"],
-            "APPLICATION_NAME": application_info["application_name"],
-            "APPLICATION_ENV": application_info["environment"],
+            "APPLICATION_FILESYSTEM_PATH": str(application_info["base_dir"]),
+            "APPLICATION_NAME": str(application_info["application_name"]),
+            "APPLICATION_ENV": str(application_info["environment"]),
         }
 
         if self.transaction_type in ['custom', 'lambda', 'azure']:
@@ -216,11 +216,11 @@ class Transaction(object):
             base_object["URL"] = self.context["request"]["url"]["full"]
 
             if "body" in self.context["request"]:
-                base_object["REQUEST_BODY"] = str(self.context["request"]["body"])
-                base_object["REQUEST_SIZE_BYTES"] = str(self.context["request"]["body_size"])
+                base_object["PREFIX_REQUEST_BODY"] = str(self.context["request"]["body"])
+                base_object["PREFIX_REQUEST_SIZE_BYTES"] = str(self.context["request"]["body_size"])
 
             if "headers" in self.context["request"]:
-                base_object["REQUEST_HEADERS"] = json.dumps([
+                base_object["PREFIX_REQUEST_HEADERS"] = json.dumps([
                     {key: val} for key, val
                     in iteritems(self.context["request"]["headers"])
                 ])
@@ -236,10 +236,10 @@ class Transaction(object):
             base_object["STATUS"] = str(self.context["response"]["status_code"])
 
             if "body" in self.context["response"]:
-                base_object["RESPONSE_BODY"] = str(self.context["response"]["body"])
-                base_object["RESPONSE_SIZE_BYTES"] = str(self.context["response"]["body_size"])
+                base_object["PREFIX_RESPONSE_BODY"] = str(self.context["response"]["body"])
+                base_object["PREFIX_RESPONSE_SIZE_BYTES"] = str(self.context["response"]["body_size"])
             if "headers" in self.context["response"]:
-                base_object["RESPONSE_HEADERS"] = json.dumps([
+                base_object["PREFIX_RESPONSE_HEADERS"] = json.dumps([
                     {key: val} for key, val
                     in iteritems(self.context["response"]["headers"])
                 ])
@@ -305,8 +305,9 @@ class Span(object):
                 self.context["SQL"] = self.context["SQL"][:constants.SQL_STATEMENT_MAX_LENGTH]
                 self.context["SQL_TRUNCATED"] = True
 
-        if "SQL_PARAMETERS" in self.context and (not config or not config.prefix_enabled):
-            self.context.pop("SQL_PARAMETERS")
+        if "PREFIX_SQL_PARAMETERS" in self.context and (not config or not config.prefix_enabled):
+            self.context.pop("PREFIX_SQL_PARAMETERS")
+            self.context.pop("PREFIX_SQL_PARAMETER_COUNT")
 
         if self.is_async:
             self.context["TRACETYPE"] = "ASYNC"
@@ -447,7 +448,7 @@ def set_transaction_name(name, override=True):
     if not transaction:
         return
 
-    if transaction.get_name() is None or override:
+    if not transaction.get_name() or override and name:
         transaction.set_name(name)
 
 
